# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.6] - 2022-06-22
### Added
- Calming2 program
### Changed
- Calming program renamed to Calming1
- Logo updated
- `README.md` modified
## [0.5] - 2022-05-09
### Added
- Decision-Making program
- `time_calc` function
- `time_average_calc` function
### Changed
- `AUTHORS.md` updated
- License updated
- `README.md` modified
- `Python 3.10` added to `test.yml`
- `time_convert` function modified
- `get_input_standard` function modified
- Menu updated
- Relax program renamed to Relax1
- 4-7-8 program renamed to Relax2
- 7-11 program renamed to Relax3
## [0.4] - 2021-05-12
### Added
- `start.wav`
- `well_done.wav`
- `preparing.wav`
- `requirements-splitter.py`
- 4-7-8 program
- 7-11 program
### Changed
- Sound speaker changed
- Test system modified
- Menu optimized
## [0.3] - 2021-02-09
### Changed
- Sounds bug in pypi fixed
- Icon modified
- Menu optimized
## [0.2] - 2021-01-29
### Added
- `_playsound_async` function
- `play_sound` function
- `inhale.wav`
- `exhale.wav`
- `sustain.wav`
- `retain.wav`
- `get_sound_path` function
- `program_description_print` function
- `time_convert` function
### Changed
- Menu optimized
- Test system modified
- `get_program_dict` function renamed to `get_program_data`
- `program_dict` parameter renamed to `program_data`
- `input_dict` parameter renamed to `input_data`
- `README.md` updated
## [0.1] - 2020-10-30
### Added
- Clear Mind program
- Relax program
- Calming program
- Power program
- Anti-Stress program
- Anti-Appetite program 
- Cigarette Replace program

[Unreleased]: https://github.com/sepandhaghighi/nafas/compare/v0.6...dev
[0.6]: https://github.com/sepandhaghighi/nafas/compare/v0.5...v0.6
[0.5]: https://github.com/sepandhaghighi/nafas/compare/v0.4...v0.5
[0.4]: https://github.com/sepandhaghighi/nafas/compare/v0.3...v0.4
[0.3]: https://github.com/sepandhaghighi/nafas/compare/v0.2...v0.3
[0.2]: https://github.com/sepandhaghighi/nafas/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/nafas/compare/c58087a...v0.1



